import { Concat } from './Concat.types';
/**
 * Maps the deep keys of an object to their path values.
 *
 * e.g.
 * ```ts
 * DeepPathValues<{
 *  a: {
 *   b: {
 *    c: any
 *    d: any
 *   },
 *   e: any
 *  }
 *  f: any
 * }>
 * // returns:
 * //{
 * // a: {
 * //  b: {
 * //   c: 'a.b.c'
 * //   d: 'a.b.d'
 * //  },
 * //  e: 'a.e'
 * // }
 * // f: 'f'
 * //}
 * ```
 */
export type DeepPathValues<T extends object, // The type of the object for which we want to extract deep keys.
Path extends string = '', // a string that keeps track of the current key path
Separator extends string = '.'> = {
    [Key in keyof T]: Key extends string ? T[Key] extends object ? DeepPathValues<T[Key], Concat<Path, Key, Separator>> : Concat<Path, Key, Separator> : never;
};
//# sourceMappingURL=DeepPathValues.types.d.ts.map