import React, { ReactElement } from 'react';
/** Helper type to check if element is a specific React Component  */
export declare function isComponentType<T extends React.ReactElement = React.ReactElement>(element: React.ReactNode, displayName: string): element is T;
/**
 * Filters children down to a restricted set of component types.
 *
 * Example:
 * ```ts
 * // `options` will only include `ComboboxOption` components,
 * // and log an error to the console for any invalid children
 * const options = validateChildren(children, ['ComboboxOption'])
 * ```
 *
 * @returns Array<ReactElement>
 */
export declare const validateChildren: (children: React.ReactNode, validTypes: Array<string>) => Array<ReactElement> | undefined;
//# sourceMappingURL=validateChildren.d.ts.map